@@ -13,7 +13,6 @@ mod api_cell;
 mod api_external;
 #[allow(missing_docs)]
 pub mod error;
-mod mock;
+
 pub use api_cell::*;
 pub use api_external::*;
-pub use mock::MockCellConductorApi;
