@@ -2,20 +2,16 @@
 
 use super::*;
 use crate::conductor::manager::ManagedTaskResult;
-use crate::core::workflow::countersigning_workflow::{
-    countersigning_workflow, CountersigningWorkspace,
-};
+use crate::core::workflow::countersigning_workflow::countersigning_workflow;
 use tokio::task::JoinHandle;
 use tracing::*;
 
 /// Spawn the QueueConsumer for countersigning workflow
-#[instrument(skip(env, stop, conductor_handle, workspace, cell_network, trigger_sys))]
+#[instrument(skip(space, stop, dna_network, trigger_sys))]
 pub(crate) fn spawn_countersigning_consumer(
-    env: EnvWrite,
+    space: Space,
     mut stop: sync::broadcast::Receiver<()>,
-    conductor_handle: ConductorHandle,
-    workspace: CountersigningWorkspace,
-    cell_network: HolochainP2pCell,
+    dna_network: HolochainP2pDna,
     trigger_sys: TriggerSender,
 ) -> (TriggerSender, JoinHandle<ManagedTaskResult>) {
     let (tx, mut rx) = TriggerSender::new();
@@ -31,17 +27,9 @@ pub(crate) fn spawn_countersigning_consumer(
             }
 
             // Run the workflow
-            match countersigning_workflow(&env, &workspace, &cell_network, &trigger_sys).await {
+            match countersigning_workflow(&space, &dna_network, &trigger_sys).await {
                 Ok(WorkComplete::Incomplete) => trigger_self.trigger(),
-                Err(err) => {
-                    handle_workflow_error(
-                        conductor_handle.clone(),
-                        cell_network.cell_id(),
-                        err,
-                        "countersigning failure",
-                    )
-                    .await?
-                }
+                Err(err) => handle_workflow_error(err)?,
                 _ => (),
             };
         }
