@@ -6,6 +6,7 @@ use holochain_zome_types::X25519PubKey;
 use std::sync::Arc;
 use crate::core::ribosome::HostFnAccess;
 use holochain_types::access::Permission;
+use crate::core::ribosome::RibosomeError;
 
 pub fn create_x25519_keypair(
     _ribosome: Arc<impl RibosomeT>,
@@ -22,7 +23,11 @@ pub fn create_x25519_keypair(
                 .map(|k| (*k).into())
         })
         .map_err(|keystore_error| WasmError::Host(keystore_error.to_string())),
-        _ => unreachable!(),
+        _ => Err(WasmError::Host(RibosomeError::HostFnPermissions(
+            call_context.zome.zome_name().clone(),
+            call_context.function_name().clone(),
+            "create_x25519_keypair".into()
+        ).to_string()))
     }
 }
 
